pygeodesy.heights._HeightNamed

Package pygeodesy :: Module heights :: Class _HeightNamed |
[frames] | no frames]

# Class _HeightNamed

      object --+
               |
    named._Named --+
                   |
                  _HeightNamed

Known Subclasses:
  - _HeightBase
  - , _HeightIDW

(INTERNAL) Interpolator base class.

Instance Methods
__call__(self, *llis, **wrap) Interpolate the height for one or several locations. |
height(self, lats, lons, **wrap) Must be overloaded. |
height_(self, *latlons, **wrap) Interpolate the height for each (latlons[i], latlons[i+1]) pair for i in range(0, len(latlons), 2). |
Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| datum Get the `datum` setting or the default (Datum).
| kmin Get the minimum number of knots (`int`).
| wrap Get the `wrap` setting (`bool`) or `None`.
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __call__ (self, *llis, **wrap) (Call operator) |
Interpolate the height for one or several locations. Must be overloaded. Arguments: `llis` - One or more locations (each `LatLon`), all positional. `wrap` - If `wrap=True` to wrap or normalize all `llis` locations (`bool`), overriding the `knots`' setting. Returns: A single interpolated height (`float`) or a list or tuple of interpolated heights (each `float`). Raises: `HeightError` - Insufficient number of `llis` or an invalid `lli`. `SciPyError` - A `scipy` issue. `SciPyWarning` - A `scipy` warning as exception.

### height_ (self, *latlons, **wrap) |
Interpolate the height for each (latlons[i], latlons[i+1]) pair for i in range(0, len(latlons), 2). Arguments: `latlons` - Alternating lat-/longitude pairs (each `degrees`), all positional. Returns: A tuple of interpolated heights (each `float`). See Also: Method `height` for further details.

Property Details

### datum Get the `datum` setting or the default (Datum). Get method: datum(self) - Get the `datum` setting or the default (Datum). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### kmin Get the minimum number of knots (`int`). Get method: kmin(self) - Get the minimum number of knots (`int`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### wrap Get the `wrap` setting (`bool`) or `None`. Get method: wrap(self) - Get the `wrap` setting (`bool`) or `None`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.